control.hpp

The control.hpp includes the headers in the control folder.

#### Usage

#include <boost/preprocessor/control.hpp>

#### Includes

- <boost/preprocessor/control/deduce_d.hpp>
- <boost/preprocessor/control/expr_if.hpp>
- <boost/preprocessor/control/expr_iif.hpp>
- <boost/preprocessor/control/if.hpp>
- <boost/preprocessor/control/iif.hpp>
- <boost/preprocessor/control/while.hpp>

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)